@@ -29,6 +29,7 @@ var FixedEtcdEnvVars = map[string]string{
 	"ETCD_DATA_DIR":              "/var/lib/etcd",
 	"ETCD_QUOTA_BACKEND_BYTES":   "7516192768", // 7 gig
 	"ETCD_INITIAL_CLUSTER_STATE": "existing",
+	"ETCD_ENABLE_PPROF":          "true",
 }
 
 type envVarFunc func(envVarContext envVarContext) (map[string]string, error)
@@ -261,7 +262,10 @@ func envVarSafe(nodeName string) string {
 
 func getUnsupportedArch(envVarContext envVarContext) (map[string]string, error) {
 	arch := runtime.GOARCH
-	if !strings.HasPrefix(arch, "s390") {
+	switch arch {
+	case "arm64":
+	case "s390x":
+	default:
 		// dont set unless it is defined.
 		return nil, nil
 	}
